﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Beef Noodles")]
    [Weight(400)]
    [Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class BeefNoodlesItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A tasty rice noodle topped with beef."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 12, Fat = 16, Protein = 18, Vitamins = 8 };
        public override float Calories { get { return 1200; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 4)]
    public partial class BeefNoodlesRecipe : RecipeFamily
    {
        public BeefNoodlesRecipe()
        {
            var product = new Recipe(
                "Beef Noodles",
                Localizer.DoStr("Beef Noodles"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(MeatStockItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
            new IngredientElement(typeof(BeetGreensItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
            new IngredientElement(typeof(RiceNoodlesItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
            new IngredientElement(typeof(ScrapMeatItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
                },
                    new CraftingElement<BeefNoodlesItem>(2)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(50, typeof(AdvancedCookingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(BeefNoodlesRecipe), 2f, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Beef Noodles"), typeof(BeefNoodlesRecipe));
            CraftingComponent.AddRecipe(typeof(StoveObject), this);
        }
    }
}
