﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bibingka")]
    [Weight(250)]
    [Ecopedia("Food", "Baking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class BibingkaItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Rice cake covered in leaf and set on fire."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 10, Fat = 6, Protein = 0, Vitamins = 8 };
        public override float Calories { get { return 850; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(BakingSkill), 4)]
    public partial class BibingkaRecipe : RecipeFamily
    {
        public BibingkaRecipe()
        {
            var product = new Recipe(
                "Bibingka",
                Localizer.DoStr("Bibingka"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceFlourItem), 2, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(BeetGreensItem), 4, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(WheatMilkItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(WheatCheeseItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
                },
                    new CraftingElement<BibingkaItem>(1)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(30, typeof(BakingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(BibingkaRecipe), 1.75f, typeof(BakingSkill), typeof(BakingFocusedSpeedTalent), typeof(BakingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Bibingka"), typeof(BibingkaRecipe));
            CraftingComponent.AddRecipe(typeof(BakeryOvenObject), this);
        }
    }
}
