﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Biko")]
    [Weight(400)]
    [Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class BikoItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Sweet, sticky rice."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 16, Fat = 14, Protein = 0, Vitamins = 0 };
        public override float Calories { get { return 900; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 6)]
    public partial class BikoRecipe : RecipeFamily
    {
        public BikoRecipe()
        {
            var product = new Recipe(
                "Biko",
                Localizer.DoStr("Biko"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(BoiledRiceItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
                },
                    new CraftingElement<BikoItem>(2)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(40, typeof(AdvancedCookingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(BikoRecipe), 2f, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Biko"), typeof(BikoRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}
