﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Carioca")]
    [Weight(150)]
    [Ecopedia("Food", "Campfire", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class CariocaItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Fried glutinous rice balls on a stick, dipped in melted sugar"); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 8, Fat = 6, Protein = 0, Vitamins = 2 };
        public override float Calories { get { return 750; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CampfireCookingSkill), 6)]
    public partial class CariocaRecipe : RecipeFamily
    {
        public CariocaRecipe()
        {
            var product = new Recipe(
                "Carioca",
                Localizer.DoStr("Carioca"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(OilItem), 2),
            new IngredientElement(typeof(RiceFlourItem), 3),
            new IngredientElement(typeof(SugarItem), 1),
            new IngredientElement(typeof(PlantFibersItem), 1),
                },
                    new CraftingElement<CariocaItem>(2)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(30, typeof(CampfireCookingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(CariocaRecipe), 1.75f, typeof(CampfireCookingSkill), typeof(CampfireCookingFocusedSpeedTalent), typeof(CampfireCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Carioca"), typeof(CariocaRecipe));
            CraftingComponent.AddRecipe(typeof(CampfireObject), this);
        }
    }
}
