﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Champorado")]
    [Weight(350)]
    [Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class ChamporadoItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Chocolate Rice Porridge."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 16, Fat = 10, Protein = 8, Vitamins = 12 };
        public override float Calories { get { return 400; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 6)]
    public partial class ChamporadoRecipe : RecipeFamily
    {
        public ChamporadoRecipe()
        {
            var product = new Recipe(
                "Champorado",
                Localizer.DoStr("Champorado"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(BoiledRiceItem), 3, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
            new IngredientElement(typeof(CharredBeansItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
                },
                    new CraftingElement<ChamporadoItem>(1)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(30, typeof(AdvancedCookingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(ChamporadoRecipe), 1.5f, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Champorado"), typeof(ChamporadoRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}
