﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Huckleberry Rice Muffin")]
    [Weight(125)]
    [Ecopedia("Food", "Baking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class HuckleberryRiceMuffinItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A delicious fruit and rice muffin"); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 14, Fat = 6, Protein = 2, Vitamins = 14 };
        public override float Calories { get { return 750; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(BakingSkill), 4)]
    public partial class HuckleberryRiceMuffinRecipe : RecipeFamily
    {
        public HuckleberryRiceMuffinRecipe()
        {
            var product = new Recipe(
                "Huckleberry Rice Muffin",
                Localizer.DoStr("Huckleberry Rice Muffin"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceFlourItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(FlourItem), 2, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(HuckleberriesItem), 8, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
                },
                    new CraftingElement<HuckleberryRiceMuffinItem>(2)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(30, typeof(BakingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(HuckleberryRiceMuffinRecipe), 1.5f, typeof(BakingSkill), typeof(BakingFocusedSpeedTalent), typeof(BakingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Huckleberry Rice Muffin"), typeof(HuckleberryRiceMuffinRecipe));
            CraftingComponent.AddRecipe(typeof(BakeryOvenObject), this);
        }
    }
}
