﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Palitaw")]
    [Weight(200)]
    [Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class PalitawItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Sticky rice pancakes dropped in boiling water."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 8, Fat = 8, Protein = 0, Vitamins = 0 };
        public override float Calories { get { return 600; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CookingSkill), 1)]
    public partial class PalitawRecipe : RecipeFamily
    {
        public PalitawRecipe()
        {
            var product = new Recipe(
                "Palitaw",
                Localizer.DoStr("Palitaw"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceFlourItem), 2, typeof(CookingSkill), typeof(CookingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 1, typeof(CookingSkill), typeof(CookingLavishResourcesTalent)),
                },
                    new CraftingElement<PalitawItem>(1)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(30, typeof(CookingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(PalitawRecipe), 1.5f, typeof(CookingSkill), typeof(CookingFocusedSpeedTalent), typeof(CookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Palitaw"), typeof(PalitawRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}
