﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Puto")]
    [Weight(125)]
    [Ecopedia("Food", "Baking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class PutoItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("Bite-sized steamed cakes made with rice flour."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 12, Fat = 8, Protein = 2, Vitamins = 2 };
        public override float Calories { get { return 850; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(BakingSkill), 4)]
    public partial class PutoRecipe : RecipeFamily
    {
        public PutoRecipe()
        {
            var product = new Recipe(
                "Puto",
                Localizer.DoStr("Puto"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceFlourItem), 3, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 2, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(WheatMilkItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
            new IngredientElement(typeof(WheatCheeseItem), 1, typeof(BakingSkill), typeof(BakingLavishResourcesTalent)),
                },
                    new CraftingElement<PutoItem>(3)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(40, typeof(BakingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(PutoRecipe), 1.5f, typeof(BakingSkill), typeof(BakingFocusedSpeedTalent), typeof(BakingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Puto"), typeof(PutoRecipe));
            CraftingComponent.AddRecipe(typeof(BakeryOvenObject), this);
        }
    }
}
