﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Rice Cookies")]
    [Weight(100)]
    [Ecopedia("Food", "Baking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class RiceCookiesItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A calorie loaded form of rice."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 12, Fat = 10, Protein = 0, Vitamins = 8 };
        public override float Calories { get { return 1100; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedBakingSkill), 2)]
    public partial class RiceCookiesRecipe : RecipeFamily
    {
        public RiceCookiesRecipe()
        {
            var product = new Recipe(
                "Rice Cookies",
                Localizer.DoStr("Rice Cookies"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceFlourItem), 3, typeof(AdvancedBakingSkill), typeof(AdvancedBakingLavishResourcesTalent)),
            new IngredientElement(typeof(WheatItem), 2, typeof(AdvancedBakingSkill), typeof(AdvancedBakingLavishResourcesTalent)),
            new IngredientElement(typeof(SugarItem), 1, typeof(AdvancedBakingSkill), typeof(AdvancedBakingLavishResourcesTalent)),
                },
                    new CraftingElement<RiceCookiesItem>(3)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(25, typeof(AdvancedBakingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(RiceCookiesRecipe), 1.5f, typeof(AdvancedBakingSkill), typeof(AdvancedBakingFocusedSpeedTalent), typeof(AdvancedBakingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Rice Cookies"), typeof(RiceCookiesRecipe));
            CraftingComponent.AddRecipe(typeof(BakeryOvenObject), this);
        }
    }
}
