﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Rice Flour")]
    [Weight(200)]
    [Ecopedia("Food", "Ingredients", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class RiceFlourItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A fine, milled rice product that's useful for making rice dishes."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 6, Fat = 4, Protein = 0, Vitamins = 2 };
        public override float Calories { get { return 300; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(MillingSkill), 4)]
    public partial class RiceFlourRecipe : RecipeFamily
    {
        public RiceFlourRecipe()
        {
            var product = new Recipe(
                "Rice Flour",
                Localizer.DoStr("Rice Flour"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceItem), 8, typeof(MillingSkill), typeof(MillingLavishResourcesTalent)),
                },
                    new CraftingElement<RiceFlourItem>(1)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(MillingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(RiceFlourRecipe), 1f, typeof(MillingSkill), typeof(MillingFocusedSpeedTalent), typeof(MillingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Rice Flour"), typeof(RiceFlourRecipe));
            CraftingComponent.AddRecipe(typeof(MillObject), this);
        }
    }
}
