﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Rice Noodles")]
    [Weight(300)]
    [Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class RiceNoodlesItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A tasty rice noodle."); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 12, Fat = 8, Protein = 2, Vitamins = 2 };
        public override float Calories { get { return 450; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CookingSkill), 4)]
    public partial class RiceNoodlesRecipe : RecipeFamily
    {
        public RiceNoodlesRecipe()
        {
            var product = new Recipe(
                "Rice Noodles",
                Localizer.DoStr("Rice Noodles"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(RiceFlourItem), 3, typeof(CookingSkill), typeof(CookingLavishResourcesTalent))//,
            //new IngredientElement(typeof(BucketOfWaterItem), 1, true),
                },
                    new CraftingElement<RiceNoodlesItem>(2)//,
                    //new CraftingElement<BucketItem>(1)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(60, typeof(CookingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(RiceNoodlesRecipe), 1.2f, typeof(CookingSkill), typeof(CookingFocusedSpeedTalent), typeof(CookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Rice Noodles"), typeof(RiceNoodlesRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}
