﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Wheat Butter")]
    [Weight(200)]
    [Ecopedia("Food", "Ingredients", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class WheatButterItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A butter like paste formed from Wheat Cream"); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 10, Fat = 10, Protein = 4, Vitamins = 6 };
        public override float Calories { get { return 350; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }


    [RequiresSkill(typeof(MillingSkill), 4)]
    public partial class WheatButterRecipe : RecipeFamily
    {
        public WheatButterRecipe()
        {
            var product = new Recipe(
                "Wheat Butter",
                Localizer.DoStr("Wheat Butter"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(WheatCreamItem), 2, typeof(MillingSkill), typeof(MillingLavishResourcesTalent)),
                },
                    new CraftingElement<WheatButterItem>(2)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(35, typeof(MillingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(WheatButterRecipe), 1.5f, typeof(MillingSkill), typeof(MillingFocusedSpeedTalent), typeof(MillingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Wheat Butter"), typeof(WheatButterRecipe));
            CraftingComponent.AddRecipe(typeof(MillObject), this);
        }
    }
}
