﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Wheat Cheese")]
    [Weight(400)]
    [Ecopedia("Food", "Ingredients", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class WheatCheeseItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A Sticky cheese formed from wheat milk"); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 12, Fat = 14, Protein = 4, Vitamins = 6 };
        public override float Calories { get { return 450; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }


    [RequiresSkill(typeof(MillingSkill), 4)]
    public partial class WheatCheeseRecipe : RecipeFamily
    {
        public WheatCheeseRecipe()
        {
            var product = new Recipe(
                "Wheat Cheese",
                Localizer.DoStr("Wheat Cheese"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(WheatMilkItem), 2, typeof(MillingSkill), typeof(MillingLavishResourcesTalent)),
                },
                    new CraftingElement<WheatCheeseItem>(2)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(45, typeof(MillingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(WheatCheeseRecipe), 2f, typeof(MillingSkill), typeof(MillingFocusedSpeedTalent), typeof(MillingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Wheat Cheese"), typeof(WheatCheeseRecipe));
            CraftingComponent.AddRecipe(typeof(MillObject), this);
        }
    }
}
