﻿using System;

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Wheat Milk")]
    [Weight(250)]
    [Ecopedia("Food", "Ingredients", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]

    public partial class WheatMilkItem : FoodItem
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A drinkable form of wheat"); } }

        private static Nutrients nutrition = new Nutrients() { Carbs = 10, Fat = 8, Protein = 6, Vitamins = 10 };
        public override float Calories { get { return 450; } }
        public override Nutrients Nutrition { get { return nutrition; } }
    }

    [RequiresSkill(typeof(MillingSkill), 4)]
    public partial class WheatMilkRecipe : RecipeFamily
    {
        public WheatMilkRecipe()
        {
            var product = new Recipe(
                "Wheat Milk",
                Localizer.DoStr("Wheat Milk"),
                new IngredientElement[]
                {
            new IngredientElement(typeof(WheatItem), 6, typeof(MillingSkill), typeof(MillingLavishResourcesTalent)),
            new IngredientElement("Fruit", 2, typeof(MillingSkill), typeof(MillingLavishResourcesTalent)),
            new IngredientElement("Fat", 4, typeof(MillingSkill), typeof(MillingLavishResourcesTalent)),
                },
                    new CraftingElement<WheatMilkItem>(2),
                    new CraftingElement<WheatCreamItem>(1)

            );
            this.Recipes = new List<Recipe> { product };
            this.LaborInCalories = CreateLaborInCaloriesValue(40, typeof(MillingSkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(WheatMilkRecipe), 2.5f, typeof(MillingSkill), typeof(MillingFocusedSpeedTalent), typeof(MillingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Wheat Milk"), typeof(WheatMilkRecipe));
            CraftingComponent.AddRecipe(typeof(MillObject), this);
        }
    }
}
